@@ -60,9 +60,6 @@ class DIN(TfBase, metaclass=ModelMeta):
         use_tf_attention=False,
         multi_sparse_combiner="sqrtn",
         seed=42,
-        k=10,
-        eval_batch_size=8192,
-        eval_user_num=None,
         lower_upper_bound=None,
         tf_sess_config=None,
         with_training=True,
@@ -117,9 +114,6 @@ class DIN(TfBase, metaclass=ModelMeta):
                 epsilon,
                 batch_size,
                 num_neg,
-                k,
-                eval_batch_size,
-                eval_user_num,
             )
 
     def _build_model(self):
