@@ -35,9 +35,6 @@ class SVD(EmbedBase, metaclass=ModelMeta, backend="tensorflow"):
         batch_size=256,
         num_neg=1,
         seed=42,
-        k=10,
-        eval_batch_size=8192,
-        eval_user_num=None,
         lower_upper_bound=None,
         tf_sess_config=None,
         with_training=True,
@@ -60,9 +57,6 @@ class SVD(EmbedBase, metaclass=ModelMeta, backend="tensorflow"):
                 epsilon,
                 batch_size,
                 num_neg,
-                k,
-                eval_batch_size,
-                eval_user_num,
             )
 
     def _build_model(self):
