@@ -64,9 +64,6 @@ class YouTubeRanking(TfBase, metaclass=ModelMeta):
         random_num=None,
         multi_sparse_combiner="sqrtn",
         seed=42,
-        k=10,
-        eval_batch_size=8192,
-        eval_user_num=None,
         lower_upper_bound=None,
         tf_sess_config=None,
         with_training=True,
@@ -113,9 +110,6 @@ class YouTubeRanking(TfBase, metaclass=ModelMeta):
                 epsilon,
                 batch_size,
                 num_neg,
-                k,
-                eval_batch_size,
-                eval_user_num,
             )
 
     def _build_model(self):
