@@ -5,6 +5,7 @@ import os
 
 import numpy as np
 import pandas as pd
+from numpy.random import default_rng
 
 from ..feature import (
     interaction_consumed,
@@ -60,6 +61,9 @@ class DataInfo(object):
             multi_sparse_unique_vals
         )
         self.multi_sparse_combine_info = multi_sparse_combine_info
+        # Numpy doc states that it is recommended to use new random API
+        # https://numpy.org/doc/stable/reference/random/index.html
+        self.np_rng = default_rng()
         self._n_users = None
         self._n_items = None
         self._user2id = None
@@ -220,7 +224,7 @@ class DataInfo(object):
         n_users = self.n_users
         n_items = self.n_items
         n_labels = len(self.interaction_data)
-        return "n_users: %d, n_items: %d, data sparsity: %.4f %%" % (
+        return "n_users: %d, n_items: %d, data density: %.4f %%" % (
             n_users,
             n_items,
             100 * n_labels / (n_users * n_items),
