@@ -1,80 +1,35 @@
+import math
 import numbers
 
 import numpy as np
 import pandas as pd
 from sklearn.metrics import (
-    mean_squared_error,
-    mean_absolute_error,
-    r2_score,
-    log_loss,
-    balanced_accuracy_score,
-    roc_auc_score,
-    precision_recall_curve,
     auc,
+    balanced_accuracy_score,
+    log_loss,
+    mean_absolute_error,
+    mean_squared_error,
+    precision_recall_curve,
+    r2_score,
+    roc_auc_score,
 )
 
 from .computation import (
+    build_eval_transformed_data,
     compute_preds,
     compute_probs,
     compute_recommends,
-    build_transformed_data,
+)
+from .metrics import (
+    ALLOWED_METRICS,
+    LISTWISE_METRICS,
+    POINTWISE_METRICS,
+    map_at_k,
+    ndcg_at_k,
+    precision_at_k,
+    recall_at_k,
 )
 from ..data import TransformedSet
-from .metrics import precision_at_k, recall_at_k, map_at_k, ndcg_at_k
-from .metrics import POINTWISE_METRICS, LISTWISE_METRICS, ALLOWED_METRICS
-
-
-def print_metrics(
-    model,
-    train_data=None,
-    eval_data=None,
-    metrics=None,
-    eval_batch_size=8192,
-    k=10,
-    sample_user_num=2048,
-    seed=42,
-):
-    if not metrics:
-        metrics = ["loss"]
-    metrics = _check_metrics(model.task, metrics, k)
-
-    if model.task == "rating":
-        if train_data:
-            y_pred, y_true = compute_preds(model, train_data, eval_batch_size)
-            # y_true = train_data.labels
-            print_metrics_rating(metrics, y_true, y_pred, train=True)
-        if eval_data:
-            y_pred, y_true = compute_preds(model, eval_data, eval_batch_size)
-            # y_true = eval_data.labels
-            print_metrics_rating(metrics, y_true, y_pred, train=False)
-
-    elif model.task == "ranking":
-        if train_data:
-            train_params = dict()
-            if POINTWISE_METRICS.intersection(metrics):
-                train_params["y_prob"], train_params["y_true"] = compute_probs(
-                    model, train_data, eval_batch_size
-                )
-                # train_params["y_true"] = train_data.labels
-
-            print_metrics_ranking(metrics, **train_params, train=True)
-
-        if eval_data:
-            test_params = dict()
-            if POINTWISE_METRICS.intersection(metrics):
-                test_params["y_prob"], test_params["y_true"] = compute_probs(
-                    model, eval_data, eval_batch_size
-                )
-                # test_params["y_true"] = eval_data.labels
-
-            if LISTWISE_METRICS.intersection(metrics):
-                chosen_users = sample_user(eval_data, seed, sample_user_num)
-                test_params["y_reco_list"], test_params["users"] = compute_recommends(
-                    model, chosen_users, k
-                )
-                test_params["y_true_list"] = eval_data.user_consumed
-
-            print_metrics_ranking(metrics, **test_params, k=k, train=False)
 
 
 def _check_metrics(task, metrics, k):
@@ -95,11 +50,54 @@ def _check_metrics(task, metrics, k):
     return metrics
 
 
+def print_metrics(
+    model,
+    train_data=None,
+    eval_data=None,
+    metrics=None,
+    eval_batch_size=8192,
+    k=10,
+    sample_user_num=2048,
+    seed=42,
+):
+    if not metrics:
+        metrics = ["loss"]
+    metrics = _check_metrics(model.task, metrics, k)
+
+    if model.task == "rating":
+        if train_data:
+            y_pred, y_true = compute_preds(model, train_data, eval_batch_size)
+            print_metrics_rating(metrics, y_true, y_pred, train=True)
+        if eval_data:
+            y_pred, y_true = compute_preds(model, eval_data, eval_batch_size)
+            print_metrics_rating(metrics, y_true, y_pred, train=False)
+
+    elif model.task == "ranking":
+        if train_data and POINTWISE_METRICS.intersection(metrics):
+            y_prob, y_true = compute_probs(model, train_data, eval_batch_size)
+            log_loss_ = log_loss(y_true, y_prob, eps=1e-7)
+            print(f"\t train log_loss: {log_loss_:.4f}")
+        if eval_data:
+            if POINTWISE_METRICS.intersection(metrics):
+                y_prob, y_true = compute_probs(model, eval_data, eval_batch_size)
+                print_metrics_ranking_pointwise(metrics, y_prob, y_true)
+            if LISTWISE_METRICS.intersection(metrics):
+                chosen_users = sample_user(eval_data, seed, sample_user_num)
+                num_batch_users = max(1, math.floor(eval_batch_size / model.n_items))
+                y_true_list = eval_data.user_consumed
+                y_reco_list, users = compute_recommends(
+                    model, chosen_users, k, num_batch_users
+                )
+                print_metrics_ranking_listwise(
+                    metrics, y_reco_list, y_true_list, users, k
+                )
+
+
+# noinspection PyTypeChecker
 def sample_user(data, seed, num):
     np.random.seed(seed)
     unique_users = np.unique(data.user_indices)
-    if isinstance(num, numbers.Integral) and num < len(unique_users):
-        # noinspection PyTypeChecker
+    if isinstance(num, numbers.Integral) and 0 < num < len(unique_users):
         users = np.random.choice(unique_users, num, replace=False)
     else:
         users = unique_users
@@ -108,78 +106,6 @@ def sample_user(data, seed, num):
     return users
 
 
-# noinspection PyUnboundLocalVariable
-def evaluate(
-    model,
-    data,
-    eval_batch_size=8192,
-    metrics=None,
-    k=10,
-    sample_user_num=2048,
-    neg_sample=False,
-    update_features=False,
-    **kwargs,
-):
-    seed = kwargs.get("seed", 42)
-    if isinstance(data, pd.DataFrame):
-        data = build_transformed_data(model, data, neg_sample, update_features, seed)
-    assert isinstance(
-        data, TransformedSet
-    ), "The data from evaluation must be TransformedSet object."
-    if not metrics:
-        metrics = ["loss"]
-    metrics = _check_metrics(model.task, metrics, k)
-    eval_result = dict()
-
-    if model.task == "rating":
-        y_pred, y_true = compute_preds(
-            model,
-            data,
-            eval_batch_size,
-        )
-        for m in metrics:
-            if m in ["rmse", "loss"]:
-                eval_result[m] = np.sqrt(mean_squared_error(y_true, y_pred))
-            elif m == "mae":
-                eval_result[m] = mean_absolute_error(y_true, y_pred)
-            elif m == "r2":
-                eval_result[m] = r2_score(y_true, y_pred)
-
-    elif model.task == "ranking":
-        if POINTWISE_METRICS.intersection(metrics):
-            y_prob, y_true = compute_probs(
-                model,
-                data,
-                eval_batch_size,
-            )
-        if LISTWISE_METRICS.intersection(metrics):
-            chosen_users = sample_user(data, seed, sample_user_num)
-            y_reco_list, users = compute_recommends(model, chosen_users, k)
-            y_true_list = data.user_consumed
-
-        for m in metrics:
-            if m in ["log_loss", "loss"]:
-                eval_result[m] = log_loss(y_true, y_prob, eps=1e-7)
-            elif m == "balanced_accuracy":
-                y_pred = np.round(y_prob)
-                eval_result[m] = balanced_accuracy_score(y_true, y_pred)
-            elif m == "roc_auc":
-                eval_result[m] = roc_auc_score(y_true, y_prob)
-            elif m == "pr_auc":
-                precision, recall, _ = precision_recall_curve(y_true, y_prob)
-                eval_result[m] = auc(recall, precision)
-            elif m == "precision":
-                eval_result[m] = precision_at_k(y_true_list, y_reco_list, users, k)
-            elif m == "recall":
-                eval_result[m] = recall_at_k(y_true_list, y_reco_list, users, k)
-            elif m == "map":
-                eval_result[m] = map_at_k(y_true_list, y_reco_list, users, k)
-            elif m == "ndcg":
-                eval_result[m] = ndcg_at_k(y_true_list, y_reco_list, users, k)
-
-    return eval_result
-
-
 def print_metrics_rating(metrics, y_true, y_pred, train=True, **kwargs):
     if kwargs.get("lower_bound") and kwargs.get("upper_bound"):
         lower_bound, upper_bound = (
@@ -205,46 +131,102 @@ def print_metrics_rating(metrics, y_true, y_pred, train=True, **kwargs):
                 print(f"\t eval r2: {r_squared:.4f}")
 
 
-def print_metrics_ranking(
-    metrics,
-    y_prob=None,
-    y_true=None,
-    y_reco_list=None,
-    y_true_list=None,
-    users=None,
+def print_metrics_ranking_pointwise(metrics, y_prob, y_true):
+    for m in metrics:
+        if m in ["log_loss", "loss"]:
+            log_loss_ = log_loss(y_true, y_prob, eps=1e-7)
+            print(f"\t eval log_loss: {log_loss_:.4f}")
+        elif m == "balanced_accuracy":
+            y_pred = np.round(y_prob)
+            accuracy = balanced_accuracy_score(y_true, y_pred)
+            print(f"\t eval balanced accuracy: {accuracy:.4f}")
+        elif m == "roc_auc":
+            roc_auc = roc_auc_score(y_true, y_prob)
+            print(f"\t eval roc_auc: {roc_auc:.4f}")
+        elif m == "pr_auc":
+            precision, recall, _ = precision_recall_curve(y_true, y_prob)
+            pr_auc = auc(recall, precision)
+            print(f"\t eval pr_auc: {pr_auc:.4f}")
+
+
+def print_metrics_ranking_listwise(metrics, y_reco_list, y_true_list, users, k):
+    for m in metrics:
+        if m == "precision":
+            precision_all = precision_at_k(y_true_list, y_reco_list, users, k)
+            print(f"\t eval precision@{k}: {precision_all:.4f}")
+        elif m == "recall":
+            recall_all = recall_at_k(y_true_list, y_reco_list, users, k)
+            print(f"\t eval recall@{k}: {recall_all:.4f}")
+        elif m == "map":
+            map_all = map_at_k(y_true_list, y_reco_list, users, k)
+            print(f"\t eval map@{k}: {map_all:.4f}")
+        elif m == "ndcg":
+            ndcg_all = ndcg_at_k(y_true_list, y_reco_list, users, k)
+            print(f"\t eval ndcg@{k}: {ndcg_all:.4f}")
+
+
+def evaluate(
+    model,
+    data,
+    eval_batch_size=8192,
+    metrics=None,
     k=10,
-    train=True,
+    sample_user_num=2048,
+    neg_sample=False,
+    update_features=False,
+    seed=42,
 ):
-    if train:
+    if isinstance(data, pd.DataFrame):
+        data = build_eval_transformed_data(
+            model, data, neg_sample, update_features, seed
+        )
+    assert isinstance(
+        data, TransformedSet
+    ), "The data from evaluation must be TransformedSet object."
+    if not metrics:
+        metrics = ["loss"]
+    metrics = _check_metrics(model.task, metrics, k)
+    eval_result = dict()
+
+    if model.task == "rating":
+        y_pred, y_true = compute_preds(model, data, eval_batch_size)
         for m in metrics:
-            if m in ["log_loss", "loss"]:
-                log_loss_ = log_loss(y_true, y_prob, eps=1e-7)
-                print(f"\t train log_loss: {log_loss_:.4f}")
-    else:
-        for m in metrics:
-            if m in ["log_loss", "loss"]:
-                log_loss_ = log_loss(y_true, y_prob, eps=1e-7)
-                print(f"\t eval log_loss: {log_loss_:.4f}")
-            elif m == "balanced_accuracy":
-                y_pred = np.round(y_prob)
-                accuracy = balanced_accuracy_score(y_true, y_pred)
-                print(f"\t eval balanced accuracy: {accuracy:.4f}")
-            elif m == "roc_auc":
-                roc_auc = roc_auc_score(y_true, y_prob)
-                print(f"\t eval roc_auc: {roc_auc:.4f}")
-            elif m == "pr_auc":
-                precision, recall, _ = precision_recall_curve(y_true, y_prob)
-                pr_auc = auc(recall, precision)
-                print(f"\t eval pr_auc: {pr_auc:.4f}")
-            elif m == "precision":
-                precision_all = precision_at_k(y_true_list, y_reco_list, users, k)
-                print(f"\t eval precision@{k}: {precision_all:.4f}")
-            elif m == "recall":
-                recall_all = recall_at_k(y_true_list, y_reco_list, users, k)
-                print(f"\t eval recall@{k}: {recall_all:.4f}")
-            elif m == "map":
-                map_all = map_at_k(y_true_list, y_reco_list, users, k)
-                print(f"\t eval map@{k}: {map_all:.4f}")
-            elif m == "ndcg":
-                ndcg_all = ndcg_at_k(y_true_list, y_reco_list, users, k)
-                print(f"\t eval ndcg@{k}: {ndcg_all:.4f}")
+            if m in ["rmse", "loss"]:
+                eval_result[m] = np.sqrt(mean_squared_error(y_true, y_pred))
+            elif m == "mae":
+                eval_result[m] = mean_absolute_error(y_true, y_pred)
+            elif m == "r2":
+                eval_result[m] = r2_score(y_true, y_pred)
+
+    elif model.task == "ranking":
+        if POINTWISE_METRICS.intersection(metrics):
+            y_prob, y_true = compute_probs(model, data, eval_batch_size)
+            for m in metrics:
+                if m in ["log_loss", "loss"]:
+                    eval_result[m] = log_loss(y_true, y_prob, eps=1e-7)
+                elif m == "balanced_accuracy":
+                    y_pred = np.round(y_prob)
+                    eval_result[m] = balanced_accuracy_score(y_true, y_pred)
+                elif m == "roc_auc":
+                    eval_result[m] = roc_auc_score(y_true, y_prob)
+                elif m == "pr_auc":
+                    precision, recall, _ = precision_recall_curve(y_true, y_prob)
+                    eval_result[m] = auc(recall, precision)
+        if LISTWISE_METRICS.intersection(metrics):
+            chosen_users = sample_user(data, seed, sample_user_num)
+            num_batch_users = max(1, math.floor(eval_batch_size / model.n_items))
+            y_true_list = data.user_consumed
+            y_reco_list, users = compute_recommends(
+                model, chosen_users, k, num_batch_users
+            )
+            for m in metrics:
+                if m == "precision":
+                    eval_result[m] = precision_at_k(y_true_list, y_reco_list, users, k)
+                elif m == "recall":
+                    eval_result[m] = recall_at_k(y_true_list, y_reco_list, users, k)
+                elif m == "map":
+                    eval_result[m] = map_at_k(y_true_list, y_reco_list, users, k)
+                elif m == "ndcg":
+                    eval_result[m] = ndcg_at_k(y_true_list, y_reco_list, users, k)
+
+    return eval_result
